# -----------------------------------------------------------------------------
# From the book "Managing Enterprise Active Directory Services"
# ISBN: 0-672-32125-4
# Copyright (C) 2002 by Addison-Wesley
# Script by Robbie Allen
# 
# You have a royalty-free right to use, modify, reproduce and distribute
# this script (and/or any modified version) in any way you find useful,
# provided that you agree that Addison-Wesley or Robbie Allen has no
# warranty, obligations or liability for the script. If you modify
# the script, you must retain this copyright notice.
# -----------------------------------------------------------------------------
use strict;
use DnsCmd;

my $new_zone = 'xyz2.com';

# Create new dnscmd object and specify primary server
my $dnscmd = DnsCmd->new('dc1.xyz.com');

# Delete old A record
$dnscmd->ZoneAdd($new_zone,   # New zone name
                 '/DsPrimary'); # Zone Type
if ($dnscmd->error) {
   die "Error creating zone: ",$dnscmd->output;
}
else {
   print "Successfully created zone: ",$dnscmd->output;
}

# Disallow zone transfers
$dnscmd->Config($new_zone,'/SecureSecondarys' => 3);
die $dnscmd->output if $dnscmd->error;

# Only allow secure updates
$dnscmd->Config($new_zone,'/AllowUpdate' => 2);
die $dnscmd->output if $dnscmd->error;

# Turn on aging
$dnscmd->Config($new_zone,'/Aging' => 1);
die $dnscmd->output if $dnscmd->error;

# Scavenge at 14 days
$dnscmd->Config($new_zone,'/RefreshInterval' => 366);
die $dnscmd->output if $dnscmd->error;

$dnscmd->Config($new_zone,'/NoRefreshInterval' => 366);
die $dnscmd->output if $dnscmd->error;

print "Successfully configured zone\n";
