# -----------------------------------------------------------------------------
# From the book "Managing Enterprise Active Directory Services"
# ISBN: 0-672-32125-4
# Copyright (C) 2002 by Addison-Wesley
# Script by Robbie Allen
# 
# You have a royalty-free right to use, modify, reproduce and distribute
# this script (and/or any modified version) in any way you find useful,
# provided that you agree that Addison-Wesley or Robbie Allen has no
# warranty, obligations or liability for the script. If you modify
# the script, you must retain this copyright notice.
# -----------------------------------------------------------------------------
use strict;
use Net::LDAP;

# Link information
my $site1        = 'RTP';
my $site2        = 'Default-First-Site-Name';
my $rep_interval = 30;
my $link_cost    = 100;

my $link_name  = "$site1::$site2";
my $sites_dn   = "cn=sites,cn=configuration,dc=xyz,dc=com";
my $ipLinks_dn = "cn=IP,cn=Inter-Site Transports,$sites_dn";

# Bind information
my $server  = 'dc1.xyz.com';
my $bind    = 'administrator@xyz.com';
my $passwd  = 'password';

my $ldap = Net::LDAP->new($server) or die "$@";
my $result = $ldap->bind($bind, password => $passwd);
$result->code && die $result->error;

print "Creating link for $link_name\n";
my $site1_dn = "cn=$site1,$sites_dn";
my $site2_dn = "cn=$site2,$sites_dn";
$result = $ldap->add (
             dn   => "cn=$link_name,$ipLinks_dn",
             attr => [
                       objectclass  => 'siteLink',
                       cost         => $link_cost,
                       replinterval => $rep_interval,
                       siteList     => [$site1_dn,$site2_dn],
                     ]);
$result->code && die $result->error;
print "Link creation complete\n";
