# -----------------------------------------------------------------------------
# From the book "Managing Enterprise Active Directory Services"
# ISBN: 0-672-32125-4
# Copyright (C) 2002 by Addison-Wesley
# Script by Robbie Allen
# 
# You have a royalty-free right to use, modify, reproduce and distribute
# this script (and/or any modified version) in any way you find useful,
# provided that you agree that Addison-Wesley or Robbie Allen has no
# warranty, obligations or liability for the script. If you modify
# the script, you must retain this copyright notice.
# -----------------------------------------------------------------------------
use strict;
use Net::LDAP;

my $kcc_value = 17; # Disable both intra and inter site topology generation

my $server  = 'dc1';
my $user    = 'administrator@xyz.com';
my $passwd  = 'password';

# This could be dynamically retrieved using RootDSE
my $sites_dn = "cn=sites,cn=configuration,dc=xyz,dc=com";

my $ldap = Net::LDAP->new($server) or die "$@";
my $result = $ldap->bind($user, password => $passwd);
$result->code && die $result->error;

my $filter = "(&(objectclass=ntdssitesettings)
                (objectcategory=ntdssitesettings))";
$result = $ldap->search(base   => $sites_dn,
                        scope  => "subtree",
                        attrs  => [ ],
                        filter => $filter);
$result->code && die $result->error;
print "Setting the KCC value in all sites to $kcc_value\n\n";
my $count = 0;
foreach my $entry ($result->entries) {
   $count++;
   my $site = $entry->dn();
   print "$count. $site\n";

   $entry->replace( options => $kcc_value);
   $result = $entry->update( $ldap );
   if ($result->code) {
      print "   Error occured when setting KCC value: ",$result->error;
   }
   else {
      print "   Set KCC value\n";
   }
}
$ldap->unbind;
