# -----------------------------------------------------------------------------
# From the book "Managing Enterprise Active Directory Services"
# ISBN: 0-672-32125-4
# Copyright (C) 2002 by Addison-Wesley
# Script by Robbie Allen
# 
# You have a royalty-free right to use, modify, reproduce and distribute
# this script (and/or any modified version) in any way you find useful,
# provided that you agree that Addison-Wesley or Robbie Allen has no
# warranty, obligations or liability for the script. If you modify
# the script, you must retain this copyright notice.
# -----------------------------------------------------------------------------
use strict;
use Net::LDAP;

my $server  = 'dc1';
my $user    = 'administrator@xyz.com';
my $passwd  = 'password';

my $ldap = Net::LDAP->new($server);
my $bind = $ldap->bind($user, password => $passwd);

# Get the schemaNamingContext value
my $rootDSEObj = $ldap->search(base   => '',
                            filter => '(objectclass=*)',
                            scope  => 'base',
                            attrs => ['schemaNamingContext']);
my $schemaDN = $rootDSEObj->entry(0)->get_value('schemaNamingContext');

# Get the DN of the NTDS Settings DN for the FSMO holder
my $schemaObj = $ldap->search(base   => $schemaDN,
                        filter => '(&(objectclass=dMD)(fsmoRoleOwner=*))',
                        scope  => 'subtree',
                        attrs => ['fsmoRoleOwner']);
my $fsmoDN = $schemaObj->entry(0)->get_value('fsmoRoleOwner');

# Strip off the RDN of the NTDS Settings DN
$fsmoDN =~ s/^cn=NTDS Settings,//i;

# Get the dNSHostname attribute
my $fsmoObj = $ldap->search(base => $fsmoDN,
                         filter => '(objectclass=*)',
                         scope  => 'base',
                         attrs => ['dNSHostName']);
my $hostname = $fsmoObj->entry(0)->get_value('dNSHostName');
print "$hostname\n";
