# -----------------------------------------------------------------------------
# From the book "Managing Enterprise Active Directory Services"
# ISBN: 0-672-32125-4
# Copyright (C) 2002 by Addison-Wesley
# Script by Robbie Allen
# 
# You have a royalty-free right to use, modify, reproduce and distribute
# this script (and/or any modified version) in any way you find useful,
# provided that you agree that Addison-Wesley or Robbie Allen has no
# warranty, obligations or liability for the script. If you modify
# the script, you must retain this copyright notice.
# -----------------------------------------------------------------------------
use Net::LDAP;

my $server  = 'dc2';
my $user    = 'administrator@xyz.com';
my $passwd  = 'password';

my $ldap = Net::LDAP->new($server);
# Be sure to bind before the first RootDSE call
my $bind = $ldap->bind($user, password => $passwd);

# Update the 'becomeSchemaMaster' operational attribute
my $rootDSEObj = $ldap->search(base   => '',
                            filter => '(objectclass=*)',
                            scope  => 'base');
$rootDSEObj->entry(0)->add( becomeSchemaMaster => $server);
$rootDSEDObj->entry(0)->update( $ldap );

# Get the schemaNamingContext value
$rootDSEObj = $ldap->search(base   => '',
                            filter => '(objectclass=*)',
                            scope  => 'base',
                            attrs => ['schemaNamingContext']);
my $schema_dn = $rootDSEObj->entry(0)->get_value('schemaNamingContext');

# Get the DN of the NTDS Settings DN for the FSMO holder
my $schemaObj = $ldap->search(base   => $schema_dn,
                           filter => '(&(objectclass=dMD)(fsmoRoleOwner=*))',
                           scope  => 'subtree',
                           attrs => ['fsmoRoleOwner']);
my $fsmo_dn = $schemaObj->entry(0)->get_value('fsmoRoleOwner');

# Strip off the RDN of the NTDS Settings DN
$fsmo_dn =~ s/^cn=NTDS Settings,//i;

# Get the dNSHostname attribute
my $fsmoObj = $ldap->search(base   => $fsmo_dn,
                         filter => '(objectclass=*)',
                         scope  => 'base',
                         attrs => ['dNSHostName']);
my $hostname = $fsmoObj->entry(0)->get_value('dNSHostName');
print "$hostname\n";
