# -----------------------------------------------------------------------------
# From the book "Managing Enterprise Active Directory Services"
# ISBN: 0-672-32125-4
# Copyright (C) 2002 by Addison-Wesley
# Script by Robbie Allen
# 
# You have a royalty-free right to use, modify, reproduce and distribute
# this script (and/or any modified version) in any way you find useful,
# provided that you agree that Addison-Wesley or Robbie Allen has no
# warranty, obligations or liability for the script. If you modify
# the script, you must retain this copyright notice.
# -----------------------------------------------------------------------------
use strict;
use Net::LDAP;
use Net::LDAP::LDIF;

my $server  = 'dc1';
my $user    = 'administrator@xyz.com';
my $passwd  = 'password';

my $ldif_file = $ARGV[0] || 'app1.ldif';

my $ldap = Net::LDAP->new($server);
my $bind = $ldap->bind($user, password => $passwd);

my $schema = $ldap->schema();

my $ldif = Net::LDAP::LDIF->new( $ldif_file, "r", onerror => 'undef' );

print "Checking LDIF entries\n";
while( not $ldif->eof() ) {
    my $entry = $ldif->read_entry();

    if ( $ldif->error() ) {
       print "\nError msg: ",$ldif->error(),"\n";
       print "\nError lines:\n",$ldif->error_lines(),"\n";
       last;
    }
    # Only want to check the entries that are to be added
    elsif ($entry->exists( 'cn' ) and $entry->changetype eq 'add') {
       my $cn = $entry->get_value('cn');
       print "$cn:";
       if ($schema->is_objectclass( $cn )) {
          print "Existing class\n";
       }
       elsif ($schema->is_attribute( $cn )) {
          print "Existing attribute\n";
       }
       else {
          print "Doesn't exist\n";
       }
    }
}
$ldif->done();
