# -----------------------------------------------------------------------------
# From the book "Managing Enterprise Active Directory Services"
# ISBN: 0-672-32125-4
# Copyright (C) 2002 by Addison-Wesley
# Script by Robbie Allen
# 
# You have a royalty-free right to use, modify, reproduce and distribute
# this script (and/or any modified version) in any way you find useful,
# provided that you agree that Addison-Wesley or Robbie Allen has no
# warranty, obligations or liability for the script. If you modify
# the script, you must retain this copyright notice.
# -----------------------------------------------------------------------------
use strict;
use Net::LDAP;
use Net::LDAP::Control::Paged;
use Net::LDAP::Constant qw( LDAP_CONTROL_PAGED );

my $ldap = Net::LDAP->new('dc1', version => 3)
           or die "Could not connect to server: $@";

my $res = $ldap->bind(dn       => 'administrator@xyz.com',
                      password => 'password');
$res->code && die $res->error;

my $page = Net::LDAP::Control::Paged->new(size => 500);
my @args = ( base    => "ou=Employees,dc=xyz,dc=com",
          scope   => "subtree",
          filter  => "(&(objectClass=user)(objectCategory=Person))",
          attrs   => [ 'name' ],
          control => [ $page ] );

my $count = 0;
while ( $res = $ldap->search( @args ) ) {
   $res->code and last;

   foreach my $entry($res->entries) {
      print "Updating ",$entry->get_value('name'),"\n";
      $ldap->modify( $entry, add => { company => "XYZ Corp" });
      $count++;
   }

   # Need to set the 'Paged' cookie
   my $resp = $res->control( LDAP_CONTROL_PAGED ) or last;
   my $cookie = $resp->cookie or last;
   $page->cookie($cookie);
}
print "Total users changed: $count\n";
