# -----------------------------------------------------------------------------
# From the book "Managing Enterprise Active Directory Services"
# ISBN: 0-672-32125-4
# Copyright (C) 2002 by Addison-Wesley
# Script by Robbie Allen
# 
# You have a royalty-free right to use, modify, reproduce and distribute
# this script (and/or any modified version) in any way you find useful,
# provided that you agree that Addison-Wesley or Robbie Allen has no
# warranty, obligations or liability for the script. If you modify
# the script, you must retain this copyright notice.
# -----------------------------------------------------------------------------
use strict;
use Net::LDAP;
use Net::LDAP::Entry;

sub ADS_GROUP_TYPE_GLOBAL_GROUP       { 0x00000002 }
sub ADS_GROUP_TYPE_DOMAIN_LOCAL_GROUP { 0x00000004 }
sub ADS_GROUP_TYPE_LOCAL_GROUP        { 0x00000004 }
sub ADS_GROUP_TYPE_UNIVERSAL_GROUP    { 0x00000008 }
sub ADS_GROUP_TYPE_SECURITY_ENABLED   { 0x80000000 }

my $server  = 'dc1';
my $user    = 'administrator@xyz.com';
my $passwd  = '****';

my $ldap = Net::LDAP->new($server)
           or die "Could not connect to $server: $@";
my $bind = $ldap->bind($user, password => $passwd);
die "Could not bind to server: ", $bind->error if $bind->code;

my $group = 'My Group';
my $grpObj = Net::LDAP::Entry->new();
$grpObj->dn("cn=$group,cn=Users,dc=xyz,dc=com");
$grpObj->add(objectclass     => 'group',
             sAMAccountName  => $group,
             groupType       =>  &ADS_GROUP_TYPE_UNIVERSAL_GROUP
                               | &ADS_GROUP_TYPE_SECURITY_ENABLED
           );
my $result = $grpObj->update($ldap);
if ($result->code) {
   print "Error occurred creating group: ",$result->error,"\n";
}
else {
   print "Group created\n";
}
