# -----------------------------------------------------------------------------
# From the book "Managing Enterprise Active Directory Services"
# ISBN: 0-672-32125-4
# Copyright (C) 2002 by Addison-Wesley
# Script by Robbie Allen
# 
# You have a royalty-free right to use, modify, reproduce and distribute
# this script (and/or any modified version) in any way you find useful,
# provided that you agree that Addison-Wesley or Robbie Allen has no
# warranty, obligations or liability for the script. If you modify
# the script, you must retain this copyright notice.
# -----------------------------------------------------------------------------
use strict;
use Net::LDAP;

my $server  = 'dc1';
my $user    = 'administrator@xyz.com';
my $passwd  = 'password';

sub ADS_GROUP_TYPE_GLOBAL_GROUP       { 0x00000002 }
sub ADS_GROUP_TYPE_DOMAIN_LOCAL_GROUP { 0x00000004 }
sub ADS_GROUP_TYPE_LOCAL_GROUP        { 0x00000004 }
sub ADS_GROUP_TYPE_UNIVERSAL_GROUP    { 0x00000008 }
sub ADS_GROUP_TYPE_SECURITY_ENABLED   { 0x80000000 }

my $ldap = Net::LDAP->new($server)
           or die "Could not connect to server: $@";

my $bind = $ldap->bind($user, password => $passwd);
die "Could not bind to server: ", $bind->error if $bind->code;

my $result = $ldap->search(base=>"cn=U.Test,cn=Users,dc=xyz,dc=com",
                           scope=>'subtree',
                           filter=>'(&(objectclass=group)
                                      (objectcategory=group))');
die "Could not find group : ", $result->error if $result->code;

my ($grpObj) = $result->entries;
$grpObj->replace(grouptype => &ADS_GROUP_TYPE_GLOBAL_GROUP
                            | &ADS_GROUP_TYPE_SECURITY_ENABLED );
print "Changed group scope to Global\n";
$grpObj->update( $ldap );
